==> phoenix_widgets-1.16.5.tar.gz: lib/phoenix_product_tiles.dart <==
import 'package:flutter/material.dart';

class PhoenixProductTiles extends StatelessWidget {
  const PhoenixProductTiles({
    Key? key,
    required this.items,
    required this.onTap,
    this.crossAxisCount = 4,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  })  : sliver = true,
        super(key: key);

  const PhoenixProductTiles.box({
    Key? key,
    required this.items,
    required this.onTap,
    this.crossAxisCount = 4,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  })  : sliver = false,
        super(key: key);

  final List<PhoenixProductItem> items;
  final void Function(int) onTap;
  final int crossAxisCount;
  final Color? labelBGColor;
  final Color? labelTextColor;
  final bool sliver;
  final double radius;

  @override
  Widget build(BuildContext context) {
    if (sliver) {
      return SliverPadding(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        sliver: SliverGrid(
          delegate: SliverChildBuilderDelegate(
            (context, index) {
              var item = items[index];
              return _PhoenixProductTile(
                icon: item.icon,
                title: item.title,
                label: item.label,
                index: items.indexOf(item),
                onTap: onTap,
              );
            },
            childCount: items.length,
          ),
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: crossAxisCount,
          ),
        ),
      );
    } else {
      return Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        child: GridView.count(
          crossAxisCount: crossAxisCount,
          physics: const NeverScrollableScrollPhysics(),
          children: items
              .map(
                (item) => _PhoenixProductTile(
                  icon: item.icon,
                  title: item.title,
                  label: item.label,
                  index: items.indexOf(item),
                  onTap: onTap,
                  labelBGColor: labelBGColor,
                  labelTextColor: labelTextColor,
                  radius: radius,
                ),
              )
              .toList(),
        ),
      );
    }
  }
}

class _PhoenixProductTile extends StatelessWidget {
  const _PhoenixProductTile({
    Key? key,
    required this.icon,
    required this.title,
    this.label,
    required this.index,
    required this.onTap,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  }) : super(key: key);

  final Widget icon;
  final String title;
  final String? label;
  final int index;
  final void Function(int) onTap;
  final Color? labelBGColor;
  final Color? labelTextColor;
  final double? radius;

  @override
  Widget build(BuildContext context) {
    return TextButton(
      style: TextButton.styleFrom(
        padding: EdgeInsets.zero,
      ),
      onPressed: () {
        onTap(index);
      },
      child: Column(
        mainAxisAlignment: MainAxisAlignment.end,
        children: [
          if (label != null)
            Container(
              padding: const EdgeInsets.symmetric(vertical: 2, horizontal: 4),
              decoration: BoxDecoration(
                color: labelBGColor ?? const Color(0xFFFB7268),
                borderRadius: BorderRadius.circular(40.0),
              ),
              child: Text(
                label!,
                textAlign: TextAlign.center,
                style: Theme.of(context).textTheme.caption!.apply(
                      color: labelTextColor ?? const Color(0xFFFFFFFF),
                      fontSizeDelta: -4.0,
                      fontWeightDelta: 1,
                    ),
              ),
            ),
          CircleAvatar(
            child: icon,
            backgroundColor: const Color(0x1A67C1BF),
            radius: radius,
          ),
          Container(
            margin: const EdgeInsets.only(top: 8.0),
            child: Text(
              title,
              textAlign: TextAlign.center,
              style: Theme.of(context).textTheme.caption,
            ),
          )
        ],
      ),
    );
  }
}

class PhoenixProductItem {
  final String title;
  final Widget icon;
  final String? label;
  final String? routeName;

  PhoenixProductItem(this.title, this.icon, {this.label, this.routeName});
}

==> phoenix_widgets-1.17.4.tar.gz: lib/phoenix_product_tiles.dart <==
import 'package:flutter/material.dart';

class PhoenixProductTiles extends StatelessWidget {
  const PhoenixProductTiles({
    Key? key,
    required this.items,
    required this.onTap,
    this.crossAxisCount = 4,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  })  : sliver = true,
        super(key: key);

  const PhoenixProductTiles.box({
    Key? key,
    required this.items,
    required this.onTap,
    this.crossAxisCount = 4,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  })  : sliver = false,
        super(key: key);

  final List<PhoenixProductItem> items;
  final void Function(int) onTap;
  final int crossAxisCount;
  final Color? labelBGColor;
  final Color? labelTextColor;
  final bool sliver;
  final double radius;

  @override
  Widget build(BuildContext context) {
    if (sliver) {
      return SliverPadding(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        sliver: SliverGrid(
          delegate: SliverChildBuilderDelegate(
            (context, index) {
              var item = items[index];
              return _PhoenixProductTile(
                icon: item.icon,
                title: item.title,
                label: item.label,
                index: items.indexOf(item),
                onTap: onTap,
              );
            },
            childCount: items.length,
          ),
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: crossAxisCount,
          ),
        ),
      );
    } else {
      return Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        child: GridView.count(
          crossAxisCount: crossAxisCount,
          physics: const NeverScrollableScrollPhysics(),
          children: items
              .map(
                (item) => _PhoenixProductTile(
                  icon: item.icon,
                  title: item.title,
                  label: item.label,
                  index: items.indexOf(item),
                  onTap: onTap,
                  labelBGColor: labelBGColor,
                  labelTextColor: labelTextColor,
                  radius: radius,
                ),
              )
              .toList(),
        ),
      );
    }
  }
}

class _PhoenixProductTile extends StatelessWidget {
  const _PhoenixProductTile({
    Key? key,
    required this.icon,
    required this.title,
    this.label,
    required this.index,
    required this.onTap,
    this.labelBGColor,
    this.labelTextColor,
    this.radius = 20.0,
  }) : super(key: key);

  final Widget icon;
  final String title;
  final String? label;
  final int index;
  final void Function(int) onTap;
  final Color? labelBGColor;
  final Color? labelTextColor;
  final double? radius;

  @override
  Widget build(BuildContext context) {
    return TextButton(
      style: TextButton.styleFrom(
        padding: EdgeInsets.zero,
      ),
      onPressed: () {
        onTap(index);
      },
      child: Column(
        mainAxisAlignment: MainAxisAlignment.end,
        children: [
          if (label != null)
            Container(
              padding: const EdgeInsets.symmetric(vertical: 2, horizontal: 4),
              decoration: BoxDecoration(
                color: labelBGColor ?? const Color(0xFFFB7268),
                borderRadius: BorderRadius.circular(40.0),
              ),
              child: Text(
                label!,
                textAlign: TextAlign.center,
                style: Theme.of(context).textTheme.bodySmall!.apply(
                      color: labelTextColor ?? const Color(0xFFFFFFFF),
                      fontSizeDelta: -4.0,
                      fontWeightDelta: 1,
                    ),
              ),
            ),
          CircleAvatar(
            backgroundColor: const Color(0x1A67C1BF),
            radius: radius,
            child: icon,
          ),
          Container(
            margin: const EdgeInsets.only(top: 8.0),
            child: Text(
              title,
              textAlign: TextAlign.center,
              style: Theme.of(context).textTheme.bodySmall,
            ),
          )
        ],
      ),
    );
  }
}

class PhoenixProductItem {
  final String title;
  final Widget icon;
  final String? label;
  final String? routeName;

  PhoenixProductItem(this.title, this.icon, {this.label, this.routeName});
}
